@@ -1,6 +1,8 @@
 """ User Income Set Request Definition """
 from pydantic import BaseModel
 
+from rowantree.contracts import StoreType
+
 
 class UserIncomeSetRequest(BaseModel):
     """
@@ -8,11 +10,11 @@ class UserIncomeSetRequest(BaseModel):
 
     Attributes
     ----------
-    income_source_name: str
+    income_source_name: StoreType
         The income source name (worker type)
     amount: int
         The amount to set for the specified type. (As an absolute)
     """
 
-    income_source_name: str
+    income_source_name: StoreType
     amount: int
